<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Pro additional lib. The herein functions are provided for the "Pro" support
 * of the plugin.
 *
 * @package    report_trainingsessions
 * @author     Valery Fremaux (valery.fremaux@gmail.com)
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

/**
 * Shifts tasks start and/or end date
 */
function report_trainingsessions_shift(&$task) {
    if ($tasks[$taskid]->replay == TASK_SHIFTTO) {
        $tasks[$taskid]->to = $tasks[$taskid]->to + $tasks[$taskid]->to * MINSECS;
    }
    if ($tasks[$taskid]->replay == TASK_SHIFT) {
        $tasks[$taskid]->from = $tasks[$taskid]->from + $tasks[$taskid]->from * MINSECS;
    }
}

function report_trainingsessions_export_report() {
    // Resolve the adequate document generator to call.
    switch ($reportformat) {
        case 'xls':
            switch ($reportlayout) {
                case 'onefulluserpersheet':
                    $reporttype = 'report';
                    $range = 'user';
                    $rangeid = $user->username;
                    $uri = new moodle_url('/report/trainingsessions/tasks/groupxlsreportperuser_batch_task.php');
                    break;

                case 'oneuserperrow':
                    $reporttype = 'summary';
                    $range = 'group';
                    $rangeid = $groupid;
                    $uri = new moodle_url('/report/trainingsessions/tasks/groupxlsreportsummary_batch_task.php');
                    break;

                default:
                    $reporttype = 'sessions';
                    $range = 'user';
                    $rangeid = $user->username;
                    $uri = new moodle_url('/report/trainingsessions/tasks/userxlssessionsreport_batch_task.php');
                    break;
            }
            break;

        case 'pdf':
            switch ($reportlayout) {
                case 'onefulluserpersheet':
                    $reporttype = 'peruser';
                    $range = 'group';
                    $rangeid = $groupid;
                    break;

                case 'onefulluserperfile':
                    $reporttype = 'peruser';
                    $range = 'user';
                    $rangeid = $user->username;
                    break;

                case 'oneuserperrow':
                    $reporttype = 'summary';
                    $range = 'group';
                    $rangeid = $groupid;
                    break;

                case 'allusersessionssinglefile':
                    $reporttype = 'sessions';
                    $range = 'group';
                    $rangeid = $groupid;
                    break;

                default:
                    $reporttype = 'sessions';
                    $range = 'user';
                    $rangeid = $user->username;
            }
            break;

        case 'json':
            break;

        default:
            // Csv case.
            switch ($reportlayout) {
                default:
                    assert(1);
            }
    }

    $filenametimesession = date('Y-M-d_H-i-s', time());

    $uri = new moodle_url('/report/trainingsessions/tasks/'.$range.$reportformat.'report'.$reporttype.'_batch_task.php');
    if ($reportformat != 'json') {
        $filename = 'trainingsessions_'.$range.'_'.$rangeid.'_'.$reporttype.'_'.$filenametimesession.'.'.$reportformat;
    } else {
        $filename = '';
    }

    $timesession = time();

    $context = context_course::instance($courseid);
    $filerec = new StdClass;
    $filerec->contextid = $context->id;
    $filerec->component = 'report_trainingsessions';
    $filerec->filearea = 'reports';
    $filerec->itemid = 0;
    $filerec->filepath = '/';
    $filerec->filename = $filename;

    // Store compilation in filestore.
    if ($range == 'group') {
        report_trainingsessions_process_group_file($group, $id, $from, $to, $timesession, $uri, $filerec, $reportscope);
    } else {
        report_trainingsessions_process_user_file($user, $id, $from, $to, $timesession, $uri, $filerec, $reportscope);
    }

    $urlbase = $CFG->httpswwwroot.'/webservice/pluginfile.php';
    return self::make_file_url($urlbase, '/'.$context->id.'/report_trainingsessions/reports/0'.$filerec->filepath.$filerec->filename, true);
}