<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * This script handles the report over sessions generation in PDF for a single group.
 * It may produce a group pdf report.
 * groupid must be provided.
 * This script should be sheduled in a redirect bouncing process for maintaining
 * memory level available for huge batches.
 *
 * @package    report_trainingsessions
 * @author     Valery Fremaux (valery.fremaux@gmail.com)
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
require('../../../../config.php');
require_once($CFG->dirroot.'/blocks/use_stats/locallib.php');
require_once($CFG->dirroot.'/course/report/trainingsessions/locallib.php');
require_once($CFG->libdir.'/excellib.class.php');
require_once($CFG->dirroot.'/report/trainingsessions/pro/renderers/pdfrenderers.php');

$id = required_param('id', PARAM_INT) ; // The course id.
$groupid = required_param('groupid', PARAM_INT) ; // The group id.
$reportscope = required_param('scope', PARAM_TEXT); // Scope for reported data.
$filename = optional_param('outputname', '', PARAM_FILE);

ini_set('memory_limit', '512M');

if (!$course = $DB->get_record('course', array('id' => $id))) {
    // Do NOT print_error here as we are a document writer.
    die ('Invalid course ID');
}
$context = context_course::instance($course->id);

$config = get_config('report_trainingsessions');

$input = report_trainingsessions_batch_input($course);

// Security.

trainingsessions_back_office_access($course);

// Compute target group.

$group = $DB->get_record('groups', array('id' => $groupid));

if ($groupid) {
    $targetusers = groups_get_members($groupid);
} else {
    $targetusers = get_enrolled_users($context);
}

// Filter out non compiling users.
trainingsessions_filter_unwanted_users($targetusers);

// Print result.

if (!empty($targetusers)) {

    // Generate PDF.

    $pdf = new TCPDF('P', 'mm', 'A4', true, 'UTF-8', false);

    $pdf->SetTitle(get_string('sessionreportdoctitle', 'report_trainingsessions'));
    $pdf->setPrintHeader(false);
    $pdf->setPrintFooter(false);
    $pdf->SetAutoPageBreak(false, 0);

    // Define variables.
    // Portrait.
    $x = 20;
    $y = $config->pdfabsoluteverticaloffset;
    $lineincr = 8;
    $dblelineincr = $lineincr * 2;
    $smalllineincr = 4;

    // Set alpha to no-transparency.
    // $pdf->SetAlpha(1);

    foreach ($targetusers as $auser) {
        $pdf->AddPage();

        // Add images and lines.
        report_trainingsessions_draw_frame($pdf);
    
        // Add images and lines.
        report_trainingsessions_print_header($pdf);

        // Add images and lines.
        report_trainingsessions_print_footer($pdf);

        if ($reportscope == 'allcourses') {
            report_trainingsessions_print_usersessions($pdf, $userid, $y, $input->from, $input->to, 0);
        } else {
            report_trainingsessions_print_usersessions($pdf, $userid, $y, $input->from, $input->to, $id);
        }
        report_trainingsessions_print_signboxes($pdf, $y, array('student' => true, 'authority' => true));
    }

    // Sending HTTP headers.

    $result = $pdf->Output('', 'S');
    $loadmode = (empty($filename)) ? 'S' : 'D';
    $result = $pdf->Output($filename, $loadmode);
    if ($loadmode == 'S') {
        echo $result;
    }
}
exit(0);
// echo '200';