<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * This script handles the report generation in batch task for a single group.
 * It may produce a group csv report.
 * groupid must be provided.
 * This script should be sheduled in a redirect bouncing process for maintaining
 * memory level available for huge batches.
 *
 * @package    report_trainingsessions
 * @category   report
 * @author     Valery Fremaux (valery.fremaux@gmail.com)
 * @version    moodle 2.x
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
require('../../../../config.php');
require_once($CFG->dirroot.'/blocks/use_stats/locallib.php');
require_once($CFG->dirroot.'/report/trainingsessions/locallib.php');
require_once($CFG->dirroot.'/report/trainingsessions/pro/renderers/pdfrenderers.php');

$id = required_param('id', PARAM_INT) ; // The course id.
$groupid = required_param('groupid', PARAM_INT) ; // The group id.
$filename = optional_param('outputname', '', PARAM_FILE);

ini_set('memory_limit', '512M');

$config = get_config('report_trainingsessions');

if (!$course = $DB->get_record('course', array('id' => $id))) {
    // Do NOT print_error here as we are a document writer.
    die ('Invalid course ID');
}
$context = context_course::instance($course->id);

$input = report_trainingsessions_batch_input($course);

// Security.

report_trainingsessions_back_office_access($course);

$coursestructure = report_trainingsessions_get_course_structure($course->id, $items);

// Compute target group.

if ($groupid) {
    $targetusers = groups_get_members($groupid);
} else {
    $targetusers = get_enrolled_users($context);
}

// Filter out non compiling users.
report_trainingsessions_filter_unwanted_users($targetusers, $course);

if (!empty($targetusers)) {

    // generate PDF.
    $pdf = new TCPDF('P', 'mm', 'A4', true, 'UTF-8', false);

    $pdf->SetTitle(get_string('sessionreportdoctitle', 'report_trainingsessions'));
    $pdf->setPrintHeader(false);
    $pdf->setPrintFooter(false);
    $pdf->SetAutoPageBreak(false, 0);

    foreach ($targetusers as $auser) {
        $pdf->AddPage();

        // Define variables.
        // Portrait.
        $x = 20;
        $y = $config->pdfabsoluteverticaloffset;
        $lineincr = 8;
        $dblelineincr = $lineincr * 2;
        $smalllineincr = 4;

        // Set alpha to no-transparency.
        // $pdf->SetAlpha(1);

        // Add images and lines.
        report_trainingsessions_draw_frame($pdf);

        // Add images and lines.
        report_trainingsessions_print_header($pdf);

        // Add images and lines.
        report_trainingsessions_print_footer($pdf);

        $table = new html_table();
        $table->pdfsize2 = array('8%', '8%', '8%', '8%', '8%', '8%', '8%', '8%', '8%', '8%', '8%', '8%');
        $table->pdfalign2 = array('L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L');
        $table->pdfalign3 = array('L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L', 'L');
        $table->pdfprintinfo = array(1,1,1,1,1,1,1,1,1,1,1,1);
        $y = report_trainingsessions_print_courses_line_header($pdf, $y, $table);

        $logusers = $auser->id;
        $logs = use_stats_extract_logs($input->from, $input->to, $auser->id, $course->id);
        $aggregate = use_stats_aggregate_logs($logs, 'module', 0, $input->from, $input->to);

        report_trainingsessions_print_courses_line($pdf, $aggregate, $auser, $table);
    }

    // Sending HTTP headers.

    $loadmode = (empty($filename)) ? 'S' : 'D';
    $result = $pdf->Output($filename, $loadmode);
    if ($loadmode == 'S') {
        echo $result;
    }
}
exit(0);
// echo '200';